---
title: 결제 내역
description: 결제가 이루어진 거래내역을 조회할 수 있는 메뉴입니다.
targetVersions:
  - v1
---

## 결제내역 체계

결제내역 화면에서는 결제가 이루어진 내역을 확인할 수 있는 화면입니다.

- 결제가 시도된 날짜의 범위를 필터할 수 있는 캘린더 필터
- 결제내역의 특정 데이터를 지정하여 혹은 미지정시 전체 데이터를 통합검색을 할수 있는 통합검색
- 결제 상태, 수단, 대행사, 유형, 모드 를 지정하여 검색 할 수 있는 필터
- 검색된 내역 결과를 상태별로 통계화 한 상태별 결제건
- 결제 상태, 고객정보, 결제 수단, 결제 대행사, 결제 금액, 구분, 요청시각, 완료시각을 확인할 수 있는 결제내역 리스트 뷰
- 해당 내역의 특정 결제건의 우측 코너를 클릭하여 MID, UID 복사 및 결제취소 기
- 해당 내역의 특정 결제건을 클릭하여 확인할 수 있는 결제내역 상세정보
- 해당 내역의 특정 결제건을 클릭하여 수행 할 수 있는 결제 취소 기능
- 해당 내역의 특정 결제건을 클릭하여 수행 할 수 있는 웹훅 재전송 기능
- 검색된 내역의 총 거래액 - 총 환불액의 계산을 통하여 통화별로 확인 할 수 있는 총 매출액 기능
- 기본 결제내역 값들과 추가적으로 고객정보, 결제 대행사 정보, 카드결제 정보, 계좌결제 정보 를 선택하여 내역을 다운받을 수 있는 엑셀 다운로드 기능

위 기능들로 구성되어 있는 화면입니다.

## 캘린더 필터

![](</gitbook-assets/ko/Screen Shot 2022-06-20 at 5.23.19 PM.png>)

- 결제 요청시각 기준으로 검색하고 싶은 결제 내역의 시작 날짜 및 시각과 끝 날짜 및 시각과 끝을 지정 합니다.
  - 결제 요청이란 고객사의 고객이 결제를 시도한 시점입니다.
  - 따라서 결제 환불 및 완료 시간 기준으로는 해당 날짜 기간안 이후로 벗어 날 수 있습니다.

- 년, 월, 일, 시, 분 단위까지 지정하실 수 있습니다.

- 편의를 위해 오늘, 어제, 과거 7일, 30일, 90일 버튼을 누르셔서 빠르게 세팅 하실 수 있습니다.

- 캘린더 UI를 통해서가 아니라 직접 기간을 입력하셔서 사용하실 수 있습니다.

## 통합 검색

![](</gitbook-assets/ko/Screen Shot 2022-06-20 at 5.36.36 PM.png>)

- 결제내역의 특정값을 지정하시거나 모든 결제관련 값에 대해서 직접 입력하신 값을 검색하는 기능입니다.

- 통합검색 필터는

  - 포트원 거래번호
  - 고객사 거래번호
  - 카드사 승인번호
  - 고객 이름
  - 고객 휴대폰번호
  - 고객 이메일
  - 결제대행사 승인번호
  - 카드번호
  - 상점아이디
  - 결제환경
  - 실시간 계좌 은행
  - 가상계좌 은행
  - 계좌번호
  - 입금자명
  - 현금영수증 발급번호
  - 고객 주소
  - 취소 사유
  - 결제환경 상세
  - 주문명

  으로 이루어져 있습니다.

- 검색 로직은 like %value 입니다. 즉 값의 맨 앞에서부터 일치하는 값을 리턴합니다.
  - 추후에 주문명과 고객 주소는 like %value%로 업데이트 될 예정입니다.

## 필터

![](</gitbook-assets/ko/Screen Shot 2022-06-20 at 6.27.42 PM.png>)

- 결제상태, 결제수단, 결제대행사, 결제 유형, 결제 모드 를 필터하신뒤 결제 내역을 검색 하실수 있습니다.
  - 결제상태: 전체, 결제예정, 결제완료, 전체취소, 부분취소, 결제실패
  - 결제수단: 사용하시는 결제 수단 값
  - 결제 대행사: 사용하시는 결제 대행사 값
  - 결제유형: 전체, 정기결제, 일반결제
  - 결제모드: 전체, 실결제, 테스트 결제

## 상태별 결제 통계

![](</gitbook-assets/ko/Screen Shot 2022-06-20 at 6.37.46 PM.png>)

- 전체, 결제완료, 결제예정, 결제실패, 결제취소 로 이루어져있습니다. 검색된 전체 내역을 상태마다 분류하여 통계를 보여줍니다.
  - 결제 실패는 부분 취소와 전액 취소가 포함된 상태값입니다.

## 결제내역 리스트

![](</gitbook-assets/ko/image (277).png>)

- 결제내역 리스트뷰는 캘린더 필터, 통합검색, 필터검색에 따라 검색된 결제 내역들을 보여줍니다.

- 캘린더 필터, 통합검색, 필터검색을 설정하지 않은체 나오는 기본 내역은 현 일자부로 6개월치 전체
  결제내역 데이터를 보여줍니다.

- 보여지는 값들은 결제상태, 고객정보, 결제수단, 결제대행사, 결제금액, 구분, 요청시각, 승인시각
  입니다.
  - 고객정보는 결제시 sdk에 입력하신 고객의 이름, 이메일, 전화번호 이며 해당 순서대로 값이 있는
    순으로 보여집니다.

  - 구분은 일반결제, 정기결제, 테스트결제를 표기하며 일반결제는 빈값으로 표기됩니다.

- 요청시각 및 승인시각은 내림차순으로 보여지며 요청시각 기준으로 보일지 승인시각 기준으로 보일지는
  해당 값을 클릭하신뒤 선택하실 수 있습니다.

- 결제내역 리스트의 특정 결제건의 우측 을 누르시면 고객사 거래번호(merchant\_uid) 및 포트원 거래번호
  (imp\_uid) 를 복사하실 수 있고 결제완료, 부분취소 건에 한해서 결제취소를 하실 수 있습니다.

## 결제내역 상세정보

![](</gitbook-assets/ko/Screen Shot 2022-06-20 at 7.06.01 PM.png>)

- 결제내역 상세정보는 고객정보 섹션과 결제정보 섹션으로 나눠집니다.

- 고객정보는 고객사가 sdk 로 전달하시는 결제하는 고객의 이름, 전화번호, 이메일, 주소 입니다.

- 결제 정보는

  - 결제상태

  - 포트원 거래번호

  - 결제수단
    - 신용카드 일경우 매입사 및 마스킹된 카드번호가 보여집니다.
    - 가상계좌일 경우 계좌 은행, 예금주, 계좌번호, 입금시간이 보여집니다.
    - 계좌이체 일 경우 계좌 은행 이 보여집니다.
    - 휴대폰 소액 결제일 경우 통신사가 보여집니다.

  - 총결제금액
    - 총 결제금액은 주문금액 - 할인금액 입니다.

  - 주문금액

  - 공급가액(부가세)

  - 포인트 결제금액
    - 포인트 결제금액은 간편결제사 및 결제 대행사의 포인트를 지칭합니다.

  - 할인금액
    - 할인금액은 pg사 전문에서 내려주는 값입니다. pg사마다 유무가 다를 수 있는점 유의해 주시기 바랍니다.

  - 카드사 승인번호

  - 상점 아이디

  - 결제대행사

  - 결제대행사 승인번호
    - 결제대행사 승인번호란 결제대행사에서 부여하는 결제 id 입니다.

  - 결제환경
    - 결제환경이란 결제된 기기 및 웹/앱의 환경값을 파씽한 값입니다.

  이 있습니다.

## 결제 취소

![](</gitbook-assets/ko/Screen Shot 2022-06-20 at 8.28.25 PM.png>)

![](</gitbook-assets/ko/Screen Shot 2022-06-20 at 8.28.37 PM (1).png>)

- 결제내역 상세 내에 결제 취소를 하실 수 있습니다. 해당 페이지는 결제 완료 및 부분취소 인 결제건에 대해서는 바로들어가실 수 있습니다.

- 기본 세팅은 전액 환불로 되있으며 부분환불을 원하시는 경우는 환불 금액을 수정해주시거나 부분환불 클릭후 수정해주신뒤 하단의 결제취소 버튼을 누르면 됩니다.

- 취소를 입력하시면 포트 데이터 및 pg사에게 취소 사유 값이 저장 및 전달됩니다.

- 해당 취소건에 면세 공급가액이 포함되있을경우 해당되는 면세 공급가액 취소분을 입력하시면 됩니다.

- 관리자 콘솔에서 취소를 하셨을시 고객사의 db에 상태 업데이트를 위해 웹훅 전송을 하게됩니다.

- 가상계좌의 경우 환불계좌 정보를 추가 입력하실 수 있습니다.
  - 환불계좌 은행
  - 환불계좌 계좌번호
  - 환불계좌 예금주

## 웹훅 재발송

![](</gitbook-assets/ko/Screen Shot 2022-06-20 at 8.44.01 PM.png>)
